@@ -227,7 +227,7 @@ glade_hdy_leaflet_child_action_activate (GladeWidgetAdaptor *adaptor,
 
     glade_command_pop_group ();
   } else {
-    GWA_GET_CLASS (GTK_TYPE_CONTAINER)->child_action_activate (adaptor,
+    GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_CONTAINER)->child_action_activate (adaptor,
                                                                container,
                                                                object,
                                                                action_path);
@@ -332,7 +332,7 @@ glade_hdy_leaflet_set_property (GladeWidgetAdaptor *adaptor,
   else if (!strcmp (id, "page"))
     set_page (object, value);
   else
-    GWA_GET_CLASS (GTK_TYPE_CONTAINER)->set_property (adaptor, object, id, value);
+    GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_CONTAINER)->set_property (adaptor, object, id, value);
 }
 
 void
@@ -348,7 +348,7 @@ glade_hdy_leaflet_get_property (GladeWidgetAdaptor *adaptor,
     g_value_reset (value);
     g_value_set_int (value, get_page (GTK_CONTAINER (object)));
   } else {
-    GWA_GET_CLASS (GTK_TYPE_CONTAINER)->get_property (adaptor, object, id, value);
+    GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_CONTAINER)->get_property (adaptor, object, id, value);
   }
 }
 
@@ -374,13 +374,13 @@ verify_page (GObject      *object,
 
   if (HDY_IS_LEAFLET (object)) {
     GtkWidget *child = glade_hdy_get_nth_child (GTK_CONTAINER (object), page);
-    gboolean allow_visible;
+    gboolean navigatable;
 
     gtk_container_child_get (GTK_CONTAINER (object), child,
-                             "allow-visible", &allow_visible,
+                             "navigatable", &navigatable,
                              NULL);
 
-    if (!allow_visible)
+    if (!navigatable)
       return FALSE;
   }
 
@@ -397,8 +397,8 @@ glade_hdy_leaflet_verify_property (GladeWidgetAdaptor *adaptor,
     return verify_n_pages (object, value);
   else if (!strcmp (id, "page"))
     return verify_page (object, value);
-  else if (GWA_GET_CLASS (GTK_TYPE_CONTAINER)->verify_property)
-    return GWA_GET_CLASS (GTK_TYPE_CONTAINER)->verify_property (adaptor, object, id, value);
+  else if (GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_CONTAINER)->verify_property)
+    return GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_CONTAINER)->verify_property (adaptor, object, id, value);
 
   return TRUE;
 }
@@ -415,7 +415,7 @@ glade_hdy_leaflet_get_child_property (GladeWidgetAdaptor *adaptor,
     g_value_set_int (value, glade_hdy_get_child_index (GTK_CONTAINER (container),
                                                        GTK_WIDGET (child)));
   else
-    GWA_GET_CLASS (GTK_TYPE_CONTAINER)->child_get_property (adaptor,
+    GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_CONTAINER)->child_get_property (adaptor,
                                                             container,
                                                             child,
                                                             property_name,
@@ -436,7 +436,7 @@ glade_hdy_leaflet_set_child_property (GladeWidgetAdaptor *adaptor,
 
     glade_hdy_sync_child_positions (GTK_CONTAINER (container));
   } else {
-    GWA_GET_CLASS (GTK_TYPE_CONTAINER)->child_set_property (adaptor,
+    GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_CONTAINER)->child_set_property (adaptor,
                                                             container,
                                                             child,
                                                             property_name,
