@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2019 Alexander Mikhaylenko <exalm7659@gmail.com>
  *
- * SPDX-License-Identifier: LGPL-2.1-or-later
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 #include "config.h"
@@ -20,19 +20,17 @@
 #define DEFAULT_DURATION 250
 
 /**
- * HdyCarousel:
+ * SECTION:hdy-carousel
+ * @short_description: A paginated scrolling widget.
+ * @title: HdyCarousel
+ * @See_also: #HdyCarouselIndicatorDots, #HdyCarouselIndicatorLines
  *
- * A paginated scrolling widget.
- *
- * The `HdyCarousel` widget can be used to display a set of pages with
+ * The #HdyCarousel widget can be used to display a set of pages with
  * swipe-based navigation between them.
  *
- * [class@CarouselIndicatorDots] and [class@CarouselIndicatorLines] can be used
- * to provide page indicators for `HdyCarousel`.
+ * # CSS nodes
  *
- * ## CSS nodes
- *
- * `HdyCarousel` has a single CSS node with name `carousel`.
+ * #HdyCarousel has a single CSS node with name carousel.
  *
  * Since: 1.0
  */
@@ -50,7 +48,7 @@ struct _HdyCarousel
   GtkOrientation orientation;
   guint animation_duration;
 
-  guint scroll_timeout_id;
+  gulong scroll_timeout_id;
   gboolean can_scroll;
 };
 
@@ -362,8 +360,7 @@ scroll_event_cb (HdyCarousel *self,
   duration = MIN (self->animation_duration, DEFAULT_DURATION);
 
   self->can_scroll = FALSE;
-  self->scroll_timeout_id =
-   g_timeout_add (duration, (GSourceFunc) scroll_timeout_cb, self);
+  g_timeout_add (duration, (GSourceFunc) scroll_timeout_cb, self);
 
   return GDK_EVENT_STOP;
 }
@@ -408,7 +405,7 @@ hdy_carousel_remove (GtkContainer *container,
 {
   HdyCarousel *self = HDY_CAROUSEL (container);
 
-  if (self->scrolling_box && widget != GTK_WIDGET (self->scrolling_box))
+  if (self->scrolling_box)
     gtk_container_remove (GTK_CONTAINER (self->scrolling_box), widget);
   else
     GTK_CONTAINER_CLASS (hdy_carousel_parent_class)->remove (container, widget);
@@ -590,9 +587,9 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
   container_class->forall = hdy_carousel_forall;
 
   /**
-   * HdyCarousel:n-pages: (attributes org.gtk.Property.get=hdy_carousel_get_n_pages)
+   * HdyCarousel:n-pages:
    *
-   * The number of pages in a [class@Carousel].
+   * The number of pages in a #HdyCarousel
    *
    * Since: 1.0
    */
@@ -606,11 +603,10 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
                        G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyCarousel:position: (attributes org.gtk.Property.get=hdy_carousel_get_position)
+   * HdyCarousel:position:
    *
-   * Current scrolling position, unitless.
-   *
-   * 1 matches 1 page. Use [method@Carousel.scroll_to] for changing it.
+   * Current scrolling position, unitless. 1 matches 1 page. Use
+   * hdy_carousel_scroll_to() for changing it.
    *
    * Since: 1.0
    */
@@ -624,12 +620,10 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
                          G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyCarousel:interactive: (attributes org.gtk.Property.get=hdy_carousel_get_interactive org.gtk.Property.set=hdy_carousel_set_interactive)
+   * HdyCarousel:interactive:
    *
-   * Whether the carousel can be navigated.
-   *
-   * This can be used to temporarily disable a `HdyCarousel` to only allow
-   * navigating it in a certain state.
+   * Whether the carousel can be navigated. This can be used to temporarily
+   * disable a #HdyCarousel to only allow navigating it in a certain state.
    *
    * Since: 1.0
    */
@@ -641,7 +635,7 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyCarousel:spacing: (attributes org.gtk.Property.get=hdy_carousel_get_spacing org.gtk.Property.set=hdy_carousel_set_spacing)
+   * HdyCarousel:spacing:
    *
    * Spacing between pages in pixels.
    *
@@ -657,9 +651,9 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyCarousel:animation-duration: (attributes org.gtk.Property.get=hdy_carousel_get_animation_duration org.gtk.Property.set=hdy_carousel_set_animation_duration)
+   * HdyCarousel:animation-duration:
    *
-   * Animation duration used by [method@Carousel.scroll_to], in milliseconds.
+   * Animation duration in milliseconds, used by hdy_carousel_scroll_to().
    *
    * Since: 1.0
    */
@@ -671,11 +665,10 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyCarousel:allow-mouse-drag: (attributes org.gtk.Property.get=hdy_carousel_get_allow_mouse_drag org.gtk.Property.set=hdy_carousel_set_allow_mouse_drag)
+   * HdyCarousel:allow-mouse-drag:
    *
-   * Sets whether the [class@Carousel] can be dragged with mouse pointer.
-   *
-   * If the value is `FALSE`, dragging is only available on touch.
+   * Sets whether the #HdyCarousel can be dragged with mouse pointer. If the
+   * value is %FALSE, dragging is only available on touch.
    *
    * Since: 1.0
    */
@@ -687,11 +680,10 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyCarousel:allow-scroll-wheel: (attributes org.gtk.Property.get=hdy_carousel_get_allow_scroll_wheel org.gtk.Property.set=hdy_carousel_set_allow_scroll_wheel)
+   * HdyCarousel:allow-scroll-wheel:
    *
-   * Whether the widget will respond to scroll wheel events.
-   *
-   * If the value is `FALSE`, wheel events will be ignored.
+   * Whether the widget will respond to scroll wheel events. If the value is
+   * %FALSE, wheel events will be ignored.
    *
    * Since: 1.4
    */
@@ -703,11 +695,10 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyCarousel:allow-long-swipes: (attributes org.gtk.Property.get=hdy_carousel_get_allow_long_swipes org.gtk.Property.set=hdy_carousel_set_allow_long_swipes)
+   * HdyCarousel:allow-long-swipes:
    *
-   * Whether to allow swiping for more than one page at a time.
-   *
-   * If the value is `FALSE`, each swipe can only move to the adjacent pages.
+   * Whether to allow swiping for more than one page at a time. If the value is
+   * %FALSE, each swipe can only move to the adjacent pages.
    *
    * Since: 1.2
    */
@@ -719,9 +710,9 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * HdyCarousel:reveal-duration: (attributes org.gtk.Property.get=hdy_carousel_get_reveal_duration org.gtk.Property.set=hdy_carousel_set_reveal_duration)
+   * HdyCarousel:reveal-duration:
    *
-   * Page reveal duration, in milliseconds.
+   * Page reveal duration in milliseconds.
    *
    * Since: 1.0
    */
@@ -742,13 +733,12 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
 
   /**
    * HdyCarousel::page-changed:
-   * @self: a carousel
-   * @index: the current page
+   * @self: The #HdyCarousel instance
+   * @index: Current page
    *
-   * This signal is emitted after a page has been changed.
-   *
-   * It can be used to implement "infinite scrolling" by amending the pages
-   * after every scroll.
+   * This signal is emitted after a page has been changed. This can be used to
+   * implement "infinite scrolling" by connecting to this signal and amending
+   * the pages.
    *
    * Since: 1.0
    */
@@ -774,8 +764,6 @@ hdy_carousel_class_init (HdyCarouselClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, position_shifted_cb);
 
   gtk_widget_class_set_css_name (widget_class, "carousel");
-
-  g_type_ensure (HDY_TYPE_CAROUSEL_BOX);
 }
 
 static void
@@ -783,6 +771,7 @@ hdy_carousel_init (HdyCarousel *self)
 {
   self->allow_scroll_wheel = TRUE;
 
+  g_type_ensure (HDY_TYPE_CAROUSEL_BOX);
   gtk_widget_init_template (GTK_WIDGET (self));
 
   self->animation_duration = DEFAULT_DURATION;
@@ -800,9 +789,9 @@ hdy_carousel_init (HdyCarousel *self)
 /**
  * hdy_carousel_new:
  *
- * Creates a new `HdyCarousel`.
+ * Create a new #HdyCarousel widget.
  *
- * Returns: the newly created `HdyCarousel`
+ * Returns: The newly created #HdyCarousel widget
  *
  * Since: 1.0
  */
@@ -814,10 +803,10 @@ hdy_carousel_new (void)
 
 /**
  * hdy_carousel_prepend:
- * @self: a carousel
+ * @self: a #HdyCarousel
  * @child: a widget to add
  *
- * Prepends @child to @self.
+ * Prepends @child to @self
  *
  * Since: 1.0
  */
@@ -832,14 +821,14 @@ hdy_carousel_prepend (HdyCarousel *self,
 
 /**
  * hdy_carousel_insert:
- * @self: a carousel
+ * @self: a #HdyCarousel
  * @child: a widget to add
- * @position: the position to insert @child in
+ * @position: the position to insert @child in.
  *
  * Inserts @child into @self at position @position.
  *
- * If position is -1, or larger than the number of pages, @child will be
- * appended to the end.
+ * If position is -1, or larger than the number of pages,
+ * @child will be appended to the end.
  *
  * Since: 1.0
  */
@@ -854,9 +843,9 @@ hdy_carousel_insert (HdyCarousel *self,
 }
 /**
  * hdy_carousel_reorder:
- * @self: a carousel
+ * @self: a #HdyCarousel
  * @child: a widget to add
- * @position: the position to move @child to
+ * @position: the position to move @child to.
  *
  * Moves @child into position @position.
  *
@@ -878,13 +867,12 @@ hdy_carousel_reorder (HdyCarousel *self,
 
 /**
  * hdy_carousel_scroll_to:
- * @self: a carousel
+ * @self: a #HdyCarousel
  * @widget: a child of @self
  *
  * Scrolls to @widget position with an animation.
- *
- * [property@Carousel:animation-duration] property can be used for controlling
- * the duration.
+ * #HdyCarousel:animation-duration property can be used for controlling the
+ * duration.
  *
  * Since: 1.0
  */
@@ -899,9 +887,9 @@ hdy_carousel_scroll_to (HdyCarousel *self,
 
 /**
  * hdy_carousel_scroll_to_full:
- * @self: a carousel
+ * @self: a #HdyCarousel
  * @widget: a child of @self
- * @duration: animation duration, in milliseconds
+ * @duration: animation duration in milliseconds
  *
  * Scrolls to @widget position with an animation.
  *
@@ -927,12 +915,12 @@ hdy_carousel_scroll_to_full (HdyCarousel *self,
 }
 
 /**
- * hdy_carousel_get_n_pages: (attributes org.gtk.Method.get_property=n-pages)
- * @self: a carousel
+ * hdy_carousel_get_n_pages:
+ * @self: a #HdyCarousel
  *
  * Gets the number of pages in @self.
  *
- * Returns: the number of pages in @self
+ * Returns: The number of pages in @self
  *
  * Since: 1.0
  */
@@ -945,12 +933,12 @@ hdy_carousel_get_n_pages (HdyCarousel *self)
 }
 
 /**
- * hdy_carousel_get_position: (attributes org.gtk.Method.get_property=position)
- * @self: a carousel
+ * hdy_carousel_get_position:
+ * @self: a #HdyCarousel
  *
  * Gets current scroll position in @self. It's unitless, 1 matches 1 page.
  *
- * Returns: the scroll position
+ * Returns: The scroll position
  *
  * Since: 1.0
  */
@@ -963,12 +951,12 @@ hdy_carousel_get_position (HdyCarousel *self)
 }
 
 /**
- * hdy_carousel_get_interactive: (attributes org.gtk.Method.get_property=interactive)
- * @self: a carousel
+ * hdy_carousel_get_interactive
+ * @self: a #HdyCarousel
  *
  * Gets whether @self can be navigated.
  *
- * Returns: `TRUE` if @self can be swiped
+ * Returns: %TRUE if @self can be swiped
  *
  * Since: 1.0
  */
@@ -981,14 +969,12 @@ hdy_carousel_get_interactive (HdyCarousel *self)
 }
 
 /**
- * hdy_carousel_set_interactive: (attributes org.gtk.Method.set_property=interactive)
- * @self: a carousel
- * @interactive: whether @self can be swiped
+ * hdy_carousel_set_interactive
+ * @self: a #HdyCarousel
+ * @interactive: whether @self can be swiped.
  *
- * Sets whether @self can be navigated.
- *
- * This can be used to temporarily disable a [class@Carousel] to only allow
- * swiping in a certain state.
+ * Sets whether @self can be navigated. This can be used to temporarily disable
+ * a #HdyCarousel to only allow swiping in a certain state.
  *
  * Since: 1.0
  */
@@ -1009,12 +995,12 @@ hdy_carousel_set_interactive (HdyCarousel *self,
 }
 
 /**
- * hdy_carousel_get_spacing: (attributes org.gtk.Method.get_property=spacing)
- * @self: a carousel
+ * hdy_carousel_get_spacing:
+ * @self: a #HdyCarousel
  *
  * Gets spacing between pages in pixels.
  *
- * Returns: spacing between pages
+ * Returns: Spacing between pages
  *
  * Since: 1.0
  */
@@ -1027,8 +1013,8 @@ hdy_carousel_get_spacing (HdyCarousel *self)
 }
 
 /**
- * hdy_carousel_set_spacing: (attributes org.gtk.Method.set_property=spacing)
- * @self: a carousel
+ * hdy_carousel_set_spacing:
+ * @self: a #HdyCarousel
  * @spacing: the new spacing value
  *
  * Sets spacing between pages in pixels.
@@ -1045,12 +1031,12 @@ hdy_carousel_set_spacing (HdyCarousel *self,
 }
 
 /**
- * hdy_carousel_get_animation_duration: (attributes org.gtk.Method.get_property=animation-duration)
- * @self: a carousel
+ * hdy_carousel_get_animation_duration:
+ * @self: a #HdyCarousel
  *
- * Gets animation duration used by [method@Carousel.scroll_to].
+ * Gets animation duration used by hdy_carousel_scroll_to().
  *
- * Returns: animation duration, in milliseconds
+ * Returns: Animation duration in milliseconds
  *
  * Since: 1.0
  */
@@ -1063,11 +1049,11 @@ hdy_carousel_get_animation_duration (HdyCarousel *self)
 }
 
 /**
- * hdy_carousel_set_animation_duration: (attributes org.gtk.Method.set_property=animation-duration)
- * @self: a carousel
- * @duration: animation duration, in milliseconds
+ * hdy_carousel_set_animation_duration:
+ * @self: a #HdyCarousel
+ * @duration: animation duration in milliseconds
  *
- * Sets animation duration used by [method@Carousel.scroll_to].
+ * Sets animation duration used by hdy_carousel_scroll_to().
  *
  * Since: 1.0
  */
@@ -1086,12 +1072,12 @@ hdy_carousel_set_animation_duration (HdyCarousel *self,
 }
 
 /**
- * hdy_carousel_get_allow_mouse_drag: (attributes org.gtk.Method.get_property=allow-mouse-drag)
- * @self: a carousel
+ * hdy_carousel_get_allow_mouse_drag:
+ * @self: a #HdyCarousel
  *
- * Sets whether @self can be dragged with mouse pointer.
+ * Sets whether @self can be dragged with mouse pointer
  *
- * Returns: `TRUE` if @self can be dragged with mouse
+ * Returns: %TRUE if @self can be dragged with mouse
  *
  * Since: 1.0
  */
@@ -1104,13 +1090,12 @@ hdy_carousel_get_allow_mouse_drag (HdyCarousel *self)
 }
 
 /**
- * hdy_carousel_set_allow_mouse_drag: (attributes org.gtk.Method.set_property=allow-mouse-drag)
- * @self: a carousel
+ * hdy_carousel_set_allow_mouse_drag:
+ * @self: a #HdyCarousel
  * @allow_mouse_drag: whether @self can be dragged with mouse pointer
  *
- * Sets whether @self can be dragged with mouse pointer.
- *
- * If @allow_mouse_drag is `FALSE`, dragging is only available on touch.
+ * Sets whether @self can be dragged with mouse pointer. If @allow_mouse_drag
+ * is %FALSE, dragging is only available on touch.
  *
  * Since: 1.0
  */
@@ -1131,12 +1116,12 @@ hdy_carousel_set_allow_mouse_drag (HdyCarousel *self,
 }
 
 /**
- * hdy_carousel_get_allow_scroll_wheel: (attributes org.gtk.Method.get_property=allow-scroll-wheel)
- * @self: a carousel
+ * hdy_carousel_get_allow_scroll_wheel:
+ * @self: a #HdyCarousel
  *
  * Gets whether @self will respond to scroll wheel events.
  *
- * Returns: `TRUE` if @self will respond to scroll wheel events
+ * Returns: %TRUE if @self will respond to scroll wheel events
  *
  * Since: 1.4
  */
@@ -1149,11 +1134,12 @@ hdy_carousel_get_allow_scroll_wheel (HdyCarousel *self)
 }
 
 /**
- * hdy_carousel_set_allow_scroll_wheel: (attributes org.gtk.Method.set_property=allow-scroll-wheel)
- * @self: a carousel
- * @allow_scroll_wheel: whether @self will respond to scroll wheel events
+ * hdy_carousel_set_allow_scroll_wheel:
+ * @self: a #HdyCarousel
+ * @allow_scroll_wheel: whether @self will respond to scroll wheel events.
  *
- * Sets whether @self will respond to scroll wheel events.
+ * Sets whether @self will respond to scroll wheel events. If the value is
+ * %FALSE, wheel events will be ignored.
  *
  * Since: 1.4
  */
@@ -1174,12 +1160,13 @@ hdy_carousel_set_allow_scroll_wheel (HdyCarousel *self,
 }
 
 /**
- * hdy_carousel_get_allow_long_swipes: (attributes org.gtk.Method.get_property=allow-long-swipes)
- * @self: a carousel
+ * hdy_carousel_get_allow_long_swipes:
+ * @self: a #HdyCarousel
  *
- * Gets whether to allow swiping for more than one page at a time.
+ * Whether to allow swiping for more than one page at a time. If the value is
+ * %FALSE, each swipe can only move to the adjacent pages.
  *
- * Returns: `TRUE` if long swipes are allowed
+ * Returns: %TRUE if long swipes are allowed, %FALSE otherwise
  *
  * Since: 1.2
  */
@@ -1192,11 +1179,12 @@ hdy_carousel_get_allow_long_swipes (HdyCarousel *self)
 }
 
 /**
- * hdy_carousel_set_allow_long_swipes: (attributes org.gtk.Method.set_property=allow-long-swipes)
- * @self: a carousel
+ * hdy_carousel_set_allow_long_swipes:
+ * @self: a #HdyCarousel
  * @allow_long_swipes: whether to allow long swipes
  *
- * Sets whether to allow swiping for more than one page at a time.
+ * Sets whether to allow swiping for more than one page at a time. If the value
+ * is %FALSE, each swipe can only move to the adjacent pages.
  *
  * Since: 1.2
  */
@@ -1217,13 +1205,13 @@ hdy_carousel_set_allow_long_swipes (HdyCarousel *self,
 }
 
 /**
- * hdy_carousel_get_reveal_duration: (attributes org.gtk.Method.get_property=reveal-duration)
- * @self: a carousel
+ * hdy_carousel_get_reveal_duration:
+ * @self: a #HdyCarousel
  *
- * Gets duration of the animation used when adding or removing pages, in
+ * Gets duration of the animation used when adding or removing pages in
  * milliseconds.
  *
- * Returns: the duration
+ * Returns: Page reveal duration
  *
  * Since: 1.0
  */
@@ -1236,11 +1224,11 @@ hdy_carousel_get_reveal_duration (HdyCarousel *self)
 }
 
 /**
- * hdy_carousel_set_reveal_duration: (attributes org.gtk.Method.set_property=reveal-duration)
- * @self: a carousel
+ * hdy_carousel_set_reveal_duration:
+ * @self: a #HdyCarousel
  * @reveal_duration: the new reveal duration value
  *
- * Sets duration of the animation used when adding or removing pages, in
+ * Sets duration of the animation used when adding or removing pages in
  * milliseconds.
  *
  * Since: 1.0
