@@ -17,8 +17,8 @@ test_hdy_swipe_group_add_remove (void)
 
   group = hdy_swipe_group_new ();
 
-  swipeable1 = HDY_SWIPEABLE (hdy_carousel_new ());
-  swipeable2 = HDY_SWIPEABLE (hdy_carousel_new ());
+  swipeable1 = g_object_ref_sink (HDY_SWIPEABLE (hdy_carousel_new ()));
+  swipeable2 = g_object_ref_sink (HDY_SWIPEABLE (hdy_carousel_new ()));
 
   g_assert_cmpint (g_slist_length (hdy_swipe_group_get_swipeables (group)), ==, 0);
 
